FormFieldModel class

Constructors

FormFieldModel({required String type, required String label, required bool required, List<String>? options})

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
options List<String>?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited